function PC_Dimmer() {}

PC_Dimmer.init = function(id) {	// called when the MIDI device is opened & set up
	PC_Dimmer.id = id;	// Store the ID of this device for later use
	PC_Dimmer.directoryMode = false;
	PC_Dimmer.olddeck = 0;
	PC_Dimmer.fadersperre = false;
	PC_Dimmer.CrossfaderChangeSperreTimer = [-1, -1];
	
	engine.connectControl("[Channel1]", "beat_active", "PC_Dimmer.Deck1BeatOutputToMidi");
	engine.connectControl("[Channel2]", "beat_active", "PC_Dimmer.Deck2BeatOutputToMidi");
	engine.connectControl("[Channel1]", "playposition", "PC_Dimmer.Deck1PostionChange");
	engine.connectControl("[Channel2]", "playposition", "PC_Dimmer.Deck2PostionChange");
	engine.connectControl("[Master]", "crossfader", "PC_Dimmer.CrossfaderChange");
}

PC_Dimmer.shutdown = function(id) {	// called when the MIDI device is closed
}

PC_Dimmer.CrossfaderChange = function() { // Crossfader wurde bewegt, Deck pruefen
	// Falls Fadersperre, gleich raus
	if (PC_Dimmer.fadersperre == true) {
		return;
	}
	// Falls Fader in Mittelstellung, nichts machen und raus
	if (engine.getValue("[Master]", "crossfader") == 0) {
		return;
	}
	// Aktuelles Deck ermitteln, 0-Position = links
	var deck = 0; 
	if (engine.getValue("[Master]", "crossfader") > 0) { // Fader ist Rechts und nicht mittig
		deck = 1;
	}
	// Schauen ob das Deck gewechselt hat
	if (deck != PC_Dimmer.olddeck){
		PC_Dimmer.olddeck = deck;
		midi.sendShortMsg(0x90,0x30,0x64+deck);   // Note C an mit 64
		PC_Dimmer.fadersperre = true;
		PC_Dimmer.CrossfaderChangeSperreTimer = engine.beginTimer(1000,"PC_Dimmer.CrossfaderChangeSperre()");
	}
}

PC_Dimmer.CrossfaderChangeSperre = function() {
	engine.stopTimer(PC_Dimmer.CrossfaderChangeSperreTimer);
	PC_Dimmer.fadersperre = false;
	midi.sendShortMsg(0x90,0x30,0x0);   // Note C an mit 0
	midi.sendShortMsg(0x80,0x30,0x0);   // Note C off mit 0
	PC_Dimmer.CrossfaderChange();   // Schauen ob Deck noch aktuell ist
}

PC_Dimmer.Deck1PostionChange = function() { // Playposition hat sich gendert
	if (engine.getValue("[Master]", "crossfader") <= 0) { // Fader ist Mittig bis links
		PC_Dimmer.SendMidiMtcFullframe("[Channel1]");
	}
}

PC_Dimmer.Deck2PostionChange = function() { // Playposition hat sich gendert
	if (engine.getValue("[Master]", "crossfader") > 0) { // Fader ist Rechts und nicht mittig
		PC_Dimmer.SendMidiMtcFullframe("[Channel2]");
	}
}

PC_Dimmer.SendMidiMtcFullframe = function(deck) { // Sendet einen MTC full Frame
	var fps = 2; // 2 = 25 FPS
	var PlayPositionRest = engine.getValue(deck, "duration") * engine.getValue(deck, "playposition");
	if (PlayPositionRest < 0) {
		PlayPositionRest = 0;
	}
	// Stunden-Position berechnen und von PlayPositionRest abziehen 
	var hr = Math.floor(PlayPositionRest / 3600);
	PlayPositionRest = PlayPositionRest - (hr * 3600);
	// Minuten-Position berechnen und von PlayPositionRest abziehen
	var mn = Math.floor(PlayPositionRest / 60);
	PlayPositionRest = PlayPositionRest - (mn * 60);
	// Sekunden-Position berechnen und von PlayPositionRest abziehen
	var ss = Math.floor(PlayPositionRest);
	PlayPositionRest = PlayPositionRest - ss;
	// Frame-Position berechnen und von PlayPositionRest abziehen
	var fr = Math.floor(PlayPositionRest * 25);

	var fullframe = [0xf0,0x7f,0x7f,0x01,0x01,(16 * fps) + hr,mn,ss,fr,0xf7];
	midi.sendSysexMsg(fullframe,10);
}

PC_Dimmer.Deck1BeatOutputToMidi = function() {
    if (engine.getValue("[Master]", "crossfader") <= 0 ) { // Fader ist Mittig bis links
		if (engine.getValue("[Channel1]", "beat_active") == true ) { // Beat ist an, sende Note an
			midi.sendShortMsg(0x90,0x32,0x64);   // Note D an mit 64
		} else { // Beat ist aus, sende Note aus
			midi.sendShortMsg(0x90,0x32,0x0);   // Note D an mit 0
			midi.sendShortMsg(0x80,0x32,0x0);   // Note D off mit 0
		}
	}
}

PC_Dimmer.Deck2BeatOutputToMidi = function() {
    if (engine.getValue("[Master]", "crossfader") > 0 ) { // Fader mehr rechts
		if (engine.getValue("[Channel2]", "beat_active") == true ) { // Beat ist an, sende Note an
			midi.sendShortMsg(0x90,0x32,0x64);   // Note D an mit 64
		} else { // Beat ist aus, sende Note aus
			midi.sendShortMsg(0x90,0x32,0x0);   // Note D an mit 0
			midi.sendShortMsg(0x80,0x32,0x0);   // Note D off mit 0
		}
	}
}


// ----------- Beispiel & Source WWW
// http://mixxx.org/wiki/doku.php/midi_scripting  bei MyController.elapsedTime = function (deck) {
// http://mixxx.org/wiki/doku.php/mixxxcontrols
